local function is_camera(unit)
	for i, camera in ipairs(SecurityCamera.cameras) do
		if camera == unit then return true end
	end
end

local on_criminal_suspicion_progress = GroupAIStateBase.on_criminal_suspicion_progress
function GroupAIStateBase:on_criminal_suspicion_progress(u_suspect, u_observer, status)
	on_criminal_suspicion_progress(self, u_suspect, u_observer, status)
	if not self._ai_enabled or not self._whisper_mode or self._stealth_hud_disabled then
		return
	end

	local ignore_suspicion = u_observer:brain() and u_observer:brain()._ignore_suspicion
	local observer_is_dead = u_observer:character_damage() and u_observer:character_damage():dead()
	local is_camera = is_camera(u_observer)
	local settings = CameraDetectionIcon and CameraDetectionIcon.settings
	local settingAvailable = not not(settings and CameraDetectionIcon.settings.susColorRGB and CameraDetectionIcon.settings.detectedColorRGB)
	local susColor = settingAvailable and settings.susColorRGB
	local detectedColor = settingAvailable and settings.detectedColorRGB
	local wpColor = is_camera and (settingAvailable and Color(255, susColor.R, susColor.G, susColor.B)/255 or Color(255, 255, 165, 44)/255) or tweak_data.hud.suspicion_color
	local wpColor2 = is_camera and (settingAvailable and Color(255, detectedColor.R, detectedColor.G, detectedColor.B)/255 or tweak_data.hud.detected_color) or tweak_data.hud.detected_color

	if ignore_suspicion or observer_is_dead then
		return
	end

	local obs_key = u_observer:key()

	if managers.groupai:state():all_AI_criminals()[obs_key] then
		return
	end

	local susp_data = self._suspicion_hud_data
	local susp_key = u_suspect and u_suspect:key()


	local obs_susp_data = susp_data[obs_key]
	if not obs_susp_data then return end

	if status == "called" then

		managers.hud:change_waypoint_arrow_color(obs_susp_data.icon_id, wpColor2)

	elseif status == "calling" then

		managers.hud:change_waypoint_arrow_color(obs_susp_data.icon_id, wpColor2)
		managers.hud:change_waypoint_arrow_color(obs_susp_data.icon_id2, wpColor2)

	elseif status == true or status == "call_interrupted" then
		local icon = is_camera and "camera_indicator" or "wp_detected"
		managers.hud:change_waypoint_icon(obs_susp_data.icon_id, icon, is_camera and wpColor2)
		managers.hud:change_waypoint_arrow_color(obs_susp_data.icon_id, wpColor2)
	else
		if obs_susp_data.alerted then
			return
		end
		local icon = is_camera and "camera_indicator" or "wp_suspicious"
		managers.hud:change_waypoint_icon(obs_susp_data.icon_id, icon, is_camera and wpColor)
		managers.hud:change_waypoint_arrow_color(obs_susp_data.icon_id, wpColor)
	end
end



local _original_create_hud_suspicion_icon = GroupAIStateBase._create_hud_suspicion_icon

function GroupAIStateBase._create_hud_suspicion_icon(obs_key, u_observer, icon_name, color, icon_id)
	local icon_pos = _original_create_hud_suspicion_icon(obs_key, u_observer, icon_name, color, icon_id)

	local wp = managers.hud._hud.waypoints[icon_id]
	if icon_name == "camera_indicator" then
		wp.bitmap:set_color(color)
		wp.bitmap:set_size(38, 38)
		wp.size = Vector3(38, 38)
	end

	return icon_pos
end

